3 ms·
I've reduced the time for lengths from 0 to 64 bytes from 46.8 ns to 30.9 ns without adversely affecting longer lengths. I also knocked 2 bytes off the code siz
by brucehoult 6y ago
I've reduced the time for lengths from 0 to 64 bytes from 46.8 ns to 30.9 ns without adversely affecting longer lengths. I also knocked 2 bytes off the code size, from 26 to 24 bytes.